@@ -95,7 +95,10 @@ read_index_file__IOH <- function(fname) {
       }
 
     record <- trimws(strsplit(lines[3], ',')[[1]])
-    
+    if (length(record) == 1){
+      next
+    }
+      
     has_dynattr <- !is.null(header$dynamicAttribute)
 
     # TODO: this must also be removed...
@@ -110,13 +113,17 @@ read_index_file__IOH <- function(fname) {
       #Check for incorrect usages of reset_problem and remove them
       maxRTs <- as.numeric(info[1,])
       idx_correct <- which(maxRTs > 0)
-      info_split <- strsplit(info[2,], ';')
-      finalFVs <- as.numeric(info_split[[1]][[1]])[idx_correct]
-      instances <- as.numeric(res[1,])[idx_correct]
       if (has_dynattr){
+        info_split <- strsplit(info[2,], ';')
+        finalFVs <- as.numeric(info_split[[1]][[1]])[idx_correct]
+        
         dynamic_attrs <- info_split[[1]][[2]]
         dynamic_attrs <- dynamic_attrs[idx_correct]
       }
+      else {
+        finalFVs <- as.numeric(info[2,])[idx_correct]
+      }
+      instances <- as.numeric(res[1,])[idx_correct]
       maxRTs <- maxRTs[idx_correct]
     }
     
@@ -146,7 +153,38 @@ read_index_file__IOH <- function(fname) {
     i <- i + 1
   }
   close(f)
-  data
+  datafiles <- unlist(lapply(data, function(x) x$datafile))
+  if (length(datafiles) > length(unique(datafiles)))
+    return(merge_indexinfo(data))
+  else 
+    return(data)
+}
+
+#' Process IOHprofiler-based .info files if they contain multiple references
+#' to a single data-file
+#'
+#' This is needed to assure that the meta-information is concatenated properly
+#' and no datafile is processed more often than nessecary
+#'
+#' @param indexInfo The info-list to reduce
+#' @return a reduced version of the provided indexInfo, preserving original order
+#' @noRd
+merge_indexinfo <- function(indexInfo) {
+  datafiles <- unlist(lapply(indexInfo, function(x) x$datafile))
+  lapply(unique(datafiles), function(dfile) {
+    new_info <- list()
+    idxs <- datafiles == dfile
+    infos <- indexInfo[idxs]
+    nr_runs <- length(unlist(lapply(infos, function(x) x$instance)))
+    for (a in attributes(infos[[1]])$names) {
+      temp <- unlist(lapply(infos, function(x) x[[a]]))
+      if (length(temp) == nr_runs)
+        new_info[[a]] <- temp
+      else
+        new_info[[a]] <- unique(temp)
+    }
+    new_info
+  })
 }
 
 #' Read single-objective COCO-based .info files and extract information
@@ -917,3 +955,134 @@ locate_corrections_files <- function(path) {
   files <- list.files(path, recursive = T, pattern = "*.txt", full.names = T)
   files[stri_detect_fixed(files, 'corrections')]
 }
+
+#' Read DataSetList of OPTION-based data
+#' 
+#' Processes the data.table object created from the OPTION response into a DataSetList object
+#'
+#' @param dt The data.table object created from the OPTION request
+#' @param source The type of data which is loaded, currently either BBOB or Nevergrad
+#' @param ... Additional parameters to add to each DataSet object (e.g. function suite of nevergrad data)
+#' 
+#' @return The DataSetList extracted from the data.table provided
+#' @noRd
+convert_from_OPTION <- function(dt, source, ...) {
+  #Initialize variables used in data.table to avoid CRAN-check notes.
+  algorithm_name <- dimensionality <- benchmark_problem <- NULL
+  instance_id <- num_experiment_run <- num_function_run <- NULL
+  precision_value <- elapsed_budget <- rotated <- NULL
+  
+  
+  triplets <- unique(dt[, .(algorithm_name, dimensionality, benchmark_problem )])
+  algIds <- list()
+  DIMs <- list()
+  funcIds <- list()
+  
+  res <- list()
+  
+  idx <- 1
+  
+  for (i in seq(nrow(triplets))) {
+    algId <- triplets$algorithm_name[i]
+    DIM <- as.numeric(triplets$dimensionality[i])
+    funcId <- triplets$benchmark_problem[i]
+    
+    if (source == "BBOB") {
+      data <- dt[algorithm_name == algId & dimensionality == DIM & benchmark_problem == funcId,
+                 .(instance_id, num_experiment_run, num_function_run, precision_value)]
+      
+      funcId_no_f <- as.numeric(stri_sub(funcId, 2))
+      
+      for (iid in unique(data$instance_id)) {
+        for (rep in unique(data$num_experiment_run)) {
+          data_reduced <- data[instance_id == iid & num_experiment_run == rep, 
+                               .(num_function_run = as.numeric(num_function_run), 
+                                 precision_value =  as.numeric(precision_value))]
+
+          rows <- unique(data_reduced$num_function_run) %>% sort
+          FV <- lapply(rows,
+                       function(b) {
+                         data_reduced[num_function_run == b, precision_value]
+                       }
+          ) %>%
+            do.call(rbind, .) %>%
+            set_rownames(rows)
+          
+          data_twocol <- as.matrix(data_reduced[order(num_function_run)])
+          RT <- align_running_time(list(data_twocol), TWO_COL, maximization = F, include_param = F)
+          
+          ds <-  structure(list(RT = RT$RT, FV = FV),
+                           class = c('DataSet', 'list'),
+                           maxRT = max(rows),
+                           finalFV = min(FV),
+                           format = 'OPTION',
+                           suite = COCO,
+                           maximization = FALSE,
+                           algId = algId,
+                           instance = iid,
+                           funcId = funcId_no_f,
+                           DIM = DIM,
+                           ID = algId)
+          res[[idx]] <- ds
+          idx <- idx + 1
+          algIds <- c(algIds, algId)
+          funcIds <- c(funcIds, funcId_no_f)
+          DIMs <- c(DIMs, DIM)
+        }
+      }
+    }
+    else {
+      data <- dt[algorithm_name == algId & dimensionality == DIM & benchmark_problem == funcId,
+                 .(elapsed_budget, precision_value, rotated, noise_level)]
+      
+      for (rotation in unique(data$rotated)) {
+        for (noise_level in unique(data$noise_level)) {
+          data_reduced <- data[rotated == rotation & noise_level == noise_level,
+                               .(num_function_run = as.numeric(elapsed_budget), 
+                                 precision_value =  as.numeric(precision_value))]
+          
+          rows <- unique(data_reduced$num_function_run) %>% sort
+          FV <- lapply(rows,
+                       function(b) {
+                         data_reduced[num_function_run == b, precision_value]
+                       }
+          ) %>%
+            do.call(rbind, .) %>%
+            set_rownames(rows)
+          
+          data_twocol <- as.matrix(data_reduced[order(num_function_run)])
+          RT <- align_running_time(list(data_twocol), TWO_COL, maximization = F)
+          
+          ds <-  structure(list(RT = RT$RT, FV = FV),
+                           class = c('DataSet', 'list'),
+                           maxRT = max(rows),
+                           finalFV = min(FV),
+                           format = 'OPTION',
+                           suite = NEVERGRAD,
+                           maximization = FALSE,
+                           algId = algId,
+                           funcId = as.character(funcId),
+                           DIM = DIM,
+                           ID = algId, 
+                           rotated = rotation, 
+                           noise_level = noise_level)
+          res[[idx]] <- ds
+          idx <- idx + 1
+          algIds <- c(algIds, algId)
+          funcIds <- c(funcIds, as.character(funcId))
+          DIMs <- c(DIMs, DIM)
+        }
+      }
+    }
+  }
+  class(res) %<>% c('DataSetList')
+  attr(res, 'DIM') <- DIMs
+  attr(res, 'funcId') <- funcIds
+  attr(res, 'algId') <- algIds
+  #To be enabled when merged with version 1.6
+  # attr(res, 'ID') <- algIds
+  # attr(res, 'ID_attributes') <- c('algId')
+  attr(res, 'suite') <- source
+  attr(res, 'maximization') <- F
+  clean_DataSetList(res)
+}
