@@ -15,14 +15,15 @@ output$RTPMF.Bar.Download <- downloadHandler(
 
 get_data_RT_PMF <- reactive({
   ftarget <- input$RTPMF.Bar.Target %>% as.numeric
-  data <- subset(DATA(), algId %in% input$RTPMF.Bar.Algs)
+  data <- subset(DATA(), ID %in% input$RTPMF.Bar.Algs)
   generate_data.PMF(data, ftarget, 'by_RT')
 })
 
 render_RT_PMF <- reactive({
   withProgress({
-    plot_general_data(get_data_RT_PMF(), 'algId', 'RT', scale.ylog = input$RTPMF.Bar.Logy,
-                      x_title = "Algorithm", y_title = "Function Evaluations")
+    plot_general_data(get_data_RT_PMF(), 'ID', 'RT', scale.ylog = input$RTPMF.Bar.Logy,
+                      x_title = "Algorithm", y_title = "Function Evaluations",
+                      violin.showpoints = input$RTPMF.Bar.Points)
   # ftarget <- input$RTPMF.Bar.Target %>% as.numeric
   # data <- subset(DATA(), algId %in% input$RTPMF.Bar.Algs)
   # Plot.RT.PMF(data, ftarget, show.sample = input$RTPMF.Bar.Sample,
@@ -49,7 +50,7 @@ output$RTPMF.Hist.Download <- downloadHandler(
 
 get_data_RT_HIST <- reactive({
   ftarget <- format_FV(input$RTPMF.Hist.Target) %>% as.numeric
-  data <- subset(DATA(), algId %in% input$RTPMF.Hist.Algs)
+  data <- subset(DATA(), ID %in% input$RTPMF.Hist.Algs)
   generate_data.hist(data, ftarget, input$RTPMF.Hist.Equal, 'by_RT')
 })
 
@@ -64,7 +65,7 @@ render_RT_HIST <- reactive({
     # 
     # Plot.RT.Histogram(data, ftarget, plot_mode = input$RTPMF.Hist.Mode, 
     #                   use.equal.bins = input$RTPMF.Hist.Equal)
-    subplot_attr <- if (input$RTPMF.Hist.Mode == 'subplot') 'algId' else NULL
+    subplot_attr <- if (input$RTPMF.Hist.Mode == 'subplot') 'ID' else NULL
     plot_general_data(get_data_RT_HIST(), 'x', 'y', width = 'width', type = 'hist', 
                       subplot_attr = subplot_attr, x_title = "Function Evaluations",
                       y_title = "Runs")
